import DateTimePicker from '@react-native-community/datetimepicker';
import * as React from 'react';
import { useState } from 'react';
import { Platform, Text, TouchableOpacity, useColorScheme } from 'react-native';
import { AirshipModal } from 'react-native-airship';
import s from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler.js';
import { useTheme } from '../services/ThemeContext';
/**
 * Shows the native iOS date picker inside a modal.
 */
const DateModaliOS = (props) => {
    /**
     * Wrap the data picker component in an Airship modal.
     * This modal doesn't use the normal theme colors,
     * since the native component inside uses its own phone-based colors.
     */
    const themeMode = useColorScheme();
    const theme = useTheme();
    const { bridge, initialValue } = props;
    const [date, setDate] = useState(initialValue);
    const textStyle = {
        color: themeMode === 'dark' ? theme.dateModalTextDark : theme.dateModalTextLight,
        fontSize: theme.rem(1),
        textAlign: 'right',
        paddingHorizontal: theme.rem(1),
        paddingVertical: theme.rem(0.5)
    };
    const handleChange = useHandler((event, date) => {
        if (date != null)
            setDate(date);
    });
    const handleDone = useHandler(() => {
        bridge.resolve(date);
    });
    return (React.createElement(AirshipModal, { bridge: bridge, onCancel: handleDone, borderRadius: 0, backgroundColor: themeMode === 'dark'
            ? theme.dateModalBackgroundDark
            : theme.dateModalBackgroundLight },
        React.createElement(TouchableOpacity, { onPress: handleDone },
            React.createElement(Text, { style: textStyle }, s.strings.done)),
        React.createElement(DateTimePicker, { display: "spinner", mode: "date", onChange: handleChange, value: date, timeZoneOffsetInMinutes: 0 })));
};
/**
 * Displays the native Android date picker modal,
 * using the Airship system to manage its lifetime.
 */
export function DateModalAndroid(props) {
    const { bridge, initialValue } = props;
    const handleChange = useHandler((event, date) => {
        if (date != null)
            bridge.resolve(date);
        else
            bridge.reject(new Error('Date was undefined'));
        bridge.remove();
    });
    return (React.createElement(DateTimePicker, { mode: "date", onChange: handleChange, value: initialValue, timeZoneOffsetInMinutes: 0 }));
}
export const DateModal = Platform.OS === 'ios' ? DateModaliOS : DateModalAndroid;
