import * as React from 'react';
import { initializeLogin } from '../../actions/LoginInitActions';
import { setAppConfig } from '../../common/appConfig';
import { updateFontStyles } from '../../constants/Fonts';
import { Router } from '../navigation/Router';
import { ReduxStore } from '../services/ReduxStore';
import { changeFont } from '../services/ThemeContext';
export function LoginScreen(props) {
    const { appConfig, fontDescription = { regularFontFamily: 'System' } } = props;
    const { regularFontFamily, headingFontFamily = regularFontFamily } = fontDescription;
    const { onComplete } = props;
    // Always update legacy fonts:
    updateFontStyles(regularFontFamily, headingFontFamily);
    // Update theme fonts if they are different:
    React.useEffect(() => changeFont(regularFontFamily, headingFontFamily), [
        regularFontFamily,
        headingFontFamily
    ]);
    setAppConfig(appConfig);
    const branding = {
        appId: props.appId,
        appName: props.appName,
        backgroundImage: props.backgroundImage,
        landingSceneText: props.landingScreenText,
        parentButton: props.parentButton,
        primaryLogo: props.primaryLogo,
        primaryLogoCallback: props.primaryLogoCallback
    };
    return (React.createElement(ReduxStore, { imports: {
            accountOptions: props.accountOptions,
            context: props.context,
            initialRoute: props.initialRoute,
            onComplete,
            onLogin: props.onLogin,
            onNotificationPermit: props.onNotificationPermit,
            recoveryKey: props.recoveryLogin,
            skipSecurityAlerts: props.skipSecurityAlerts,
            username: props.username,
            customPermissionsFunction: props.customPermissionsFunction
        }, initialAction: initializeLogin() },
        React.createElement(Router, { branding: branding })));
}
