var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { FlatList, Keyboard, Platform, Text, TouchableOpacity, TouchableWithoutFeedback, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import { SafeAreaView } from 'react-native-safe-area-context';
import { SvgXml } from 'react-native-svg';
import MaterialCommunityIcons from 'react-native-vector-icons/MaterialCommunityIcons';
import { sprintf } from 'sprintf-js';
import { loginWithPin, loginWithTouch } from '../../actions/LoginAction';
import { deleteUserFromDevice } from '../../actions/UserActions';
import { FaceIdXml } from '../../assets/xml/FaceId';
import s from '../../common/locales/strings';
import { FourDigit } from '../abSpecific/FourDigitComponent';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { PinKeypad } from '../abSpecific/PinKeypad';
import { UserListItem } from '../abSpecific/UserListItem';
import { ButtonsModal } from '../modals/ButtonsModal';
import { Airship, showError } from '../services/AirshipInstance';
import { connect } from '../services/ReduxStore';
import { withTheme } from '../services/ThemeContext';
import { ThemedScene } from '../themed/ThemedScene';
class PinLoginSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handleBack = () => {
            this.exitPin();
        };
        this.handleDelete = (username) => {
            const { deleteUserFromDevice } = this.props;
            this.setState({ focusOn: 'pin' });
            Keyboard.dismiss();
            Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.forget_account, message: sprintf(s.strings.forget_username_account, username), buttons: {
                    ok: { label: s.strings.forget },
                    cancel: { label: s.strings.cancel, type: 'secondary' }
                } })))
                .then((button) => __awaiter(this, void 0, void 0, function* () {
                if (button !== 'ok')
                    return;
                return yield deleteUserFromDevice(username);
            }))
                .catch(showError);
        };
        this.handleTouchId = () => {
            this.props.loginWithTouch(this.props.username);
        };
        this.handlePress = (value) => {
            const { loginWithPin, onChangeText, pin, username } = this.props;
            const newPin = value === 'back' ? pin.slice(0, -1) : pin.concat(value).slice(0, 4);
            if (newPin.length === 4 && pin.length === 3) {
                loginWithPin(username, newPin);
            }
            onChangeText(newPin);
        };
        this.renderItems = (item) => {
            return (React.createElement(UserListItem, { data: item.item, onClick: this.handleSelectUser, onDelete: this.handleDelete }));
        };
        this.handleSelectUser = (username) => {
            this.props.loginWithTouch(username);
            this.props.changeUser(username);
            this.setState({
                focusOn: 'pin'
            });
        };
        this.handleShowDrop = () => {
            this.setState({
                focusOn: 'List'
            });
        };
        this.handleHideDrop = () => {
            this.setState({
                focusOn: 'pin'
            });
        };
        this.renderTouchImage = () => {
            const { touch, userDetails, theme } = this.props;
            const { touchEnabled } = userDetails;
            if (touchEnabled && touch === 'FaceID') {
                return (React.createElement(TouchableOpacity, { onPress: this.handleTouchId, disabled: this.props.isTouchIdDisabled },
                    React.createElement(SvgXml, { xml: FaceIdXml, color: theme.iconTappable, width: theme.rem(3), height: theme.rem(3) })));
            }
            if (touchEnabled && touch === 'TouchID') {
                return (React.createElement(TouchableOpacity, { onPress: this.handleTouchId, disabled: this.props.isTouchIdDisabled },
                    React.createElement(MaterialCommunityIcons, { name: "fingerprint", size: theme.rem(3), color: theme.iconTappable })));
            }
            if (!touchEnabled || !touch) {
                return null;
            }
            return null;
        };
        this.renderTouchImageText = () => {
            const { touch, userDetails } = this.props;
            const { touchEnabled } = userDetails;
            if (touchEnabled && touch === 'FaceID') {
                return s.strings.use_faceId;
            }
            if (touchEnabled && touch === 'TouchID' && Platform.OS === 'ios') {
                return s.strings.use_touchId;
            }
            if (touchEnabled && touch === 'TouchID' && Platform.OS !== 'ios') {
                return s.strings.use_fingerprint;
            }
            return '';
        };
        this.state = {
            focusOn: 'pin'
        };
    }
    componentDidMount() {
        if (this.props.username && this.props.touch !== 'FaceID') {
            this.props.loginWithTouch(this.props.username);
        }
    }
    componentDidUpdate() {
        if (!this.props.userDetails.touchEnabled &&
            !this.props.userDetails.pinEnabled) {
            this.exitPin();
        }
    }
    render() {
        const { theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(ThemedScene, { backButtonText: s.strings.exit_pin, onBack: this.handleBack, noUnderline: true, branding: this.props.branding },
            React.createElement(View, { style: styles.container }, this.renderOverImage())));
    }
    renderOverImage() {
        const { pin, wait, theme } = this.props;
        const styles = getStyles(theme);
        if (this.props.loginSuccess) {
            return null;
        }
        return (React.createElement(View, { style: styles.featureBoxContainer },
            React.createElement(TouchableWithoutFeedback, { onPress: this.handleHideDrop },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: this.props.branding }),
                    React.createElement(View, { style: styles.featureBoxBody }, this.renderBottomHalf()))),
            React.createElement(View, { style: styles.spacer_full }),
            !this.props.userDetails.pinEnabled ? null : (React.createElement(PinKeypad, { disabled: wait > 0 || pin.length === 4, onPress: this.handlePress })),
            React.createElement(SafeAreaView, { edges: ['bottom'] })));
    }
    renderBottomHalf() {
        const { errorMessage, isLoggingInWithPin, pin, wait, theme } = this.props;
        const styles = getStyles(theme);
        if (this.state.focusOn === 'pin') {
            return (React.createElement(View, { style: styles.innerView },
                React.createElement(TouchableOpacity, { style: styles.usernameShadow, onPress: this.handleShowDrop },
                    React.createElement(LinearGradient, { colors: theme.pinUsernameButton, start: theme.pinUsernameButtonColorStart, end: theme.pinUsernameButtonColorEnd, style: [styles.linearGradient, styles.usernameButton] },
                        React.createElement(Text, { adjustsFontSizeToFit: true, minimumFontScale: 0.75, numberOfLines: 1, style: styles.usernameText }, this.props.username))),
                !this.props.userDetails.pinEnabled ? null : (React.createElement(FourDigit, { error: wait > 0
                        ? `${errorMessage}: ${sprintf(s.strings.account_locked_for, wait)}`
                        : errorMessage, pin: pin, spinner: wait > 0 || pin.length === 4 || isLoggingInWithPin })),
                this.props.userDetails.pinEnabled ? null : (React.createElement(View, { style: styles.spacer })),
                this.renderTouchImage(),
                React.createElement(Text, { style: styles.touchImageText }, this.renderTouchImageText())));
        }
        return (React.createElement(View, { style: styles.innerView },
            React.createElement(FlatList, { style: styles.listView, data: this.getDropdownItems(), renderItem: this.renderItems, keyExtractor: (item, index) => index.toString() })));
    }
    exitPin() {
        this.props.gotoLoginPage();
    }
    getDropdownItems() {
        const { userList, touch } = this.props;
        return userList
            .filter(user => user.pinEnabled || (touch && user.touchEnabled))
            .map(user => user.username);
    }
}
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        width: '100%',
        height: '100%'
    },
    listView: {
        height: theme.rem(16),
        width: theme.rem(10)
    },
    featureBoxContainer: {
        width: '100%',
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-around'
    },
    featureBox: {
        width: '100%',
        alignItems: 'center'
    },
    featureBoxBody: {
        height: theme.rem(15),
        width: '100%'
    },
    innerView: {
        height: '100%',
        width: '100%',
        justifyContent: 'flex-start',
        alignItems: 'center'
    },
    touchImageText: {
        marginTop: theme.rem(0.5),
        color: theme.iconTappable
    },
    usernameText: {
        fontFamily: theme.pinUsernameButtonFont,
        color: theme.pinUsernameButtonText,
        fontSize: theme.rem(theme.pinUsernameButtonFontSizeRem),
        paddingHorizontal: theme.rem(1),
        paddingVertical: theme.rem(0.5)
    },
    usernameButton: {
        borderColor: theme.pinUsernameButtonOutline,
        borderWidth: theme.pinUsernameButtonOutlineWidth
    },
    usernameShadow: Object.assign({}, theme.pinUsernameButtonShadow),
    linearGradient: {
        // flex: 1,
        paddingLeft: 0,
        paddingRight: 0,
        borderRadius: theme.rem(theme.pinUsernameButtonBorderRadiusRem)
    },
    spacer: {
        marginTop: theme.rem(2)
    },
    spacer_full: {
        flex: 1,
        zIndex: -100
    }
}));
export const PinLoginScene = connect((state) => {
    var _a;
    return ({
        errorMessage: state.login.errorMessage || '',
        isLoggingInWithPin: state.login.isLoggingInWithPin,
        isTouchIdDisabled: state.login.loginSuccess ||
            !!state.login.wait ||
            state.login.isLoggingInWithPin ||
            (state.login.pin ? state.login.pin.length : 0) === 4,
        loginSuccess: state.login.loginSuccess,
        pin: state.login.pin || '',
        touch: state.touch.type,
        userDetails: (_a = state.previousUsers.userList.find(user => user.username === state.login.username)) !== null && _a !== void 0 ? _a : {
            username: state.login.username,
            pinEnabled: false,
            touchEnabled: false
        },
        userList: state.previousUsers.userList,
        username: state.login.username,
        wait: state.login.wait
    });
}, (dispatch) => ({
    changeUser: (data) => {
        dispatch({ type: 'AUTH_UPDATE_USERNAME', data: data });
    },
    deleteUserFromDevice(username) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(deleteUserFromDevice(username));
        });
    },
    gotoLoginPage: () => {
        dispatch({ type: 'START_PASSWORD_LOGIN' });
    },
    loginWithTouch(username) {
        dispatch(loginWithTouch(username)).catch(showError);
    },
    loginWithPin(username, pin) {
        dispatch(loginWithPin(username, pin));
    },
    onChangeText(pin) {
        dispatch({ type: 'AUTH_UPDATE_PIN', data: pin });
    }
}))(withTheme(PinLoginSceneComponent));
