import * as React from 'react';
import { Platform, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
// TODO: Implement alert colors such as info and others
export const useAlertTypeColor = (type) => {
    const theme = useTheme();
    switch (type) {
        case 'warning':
            return theme.warningText;
        case 'error':
            return theme.dangerText;
        default:
            return theme.primaryText;
    }
};
// TODO: Implement alert icons such as info and others
export const useAlertTypeIcon = (type, color, size, style) => {
    switch (type) {
        case 'warning':
        case 'error':
            return (React.createElement(IonIcon, { style: style, name: Platform.OS === 'ios'
                    ? 'ios-information-circle-outline'
                    : 'md-information-circle-outline', color: color, size: size }));
        default:
            return null;
    }
};
export function Alert({ type, title, message, numberOfLines = 2, marginRem, paddingRem, onPress, children }) {
    const theme = useTheme();
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 1), theme.rem));
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 1), theme.rem));
    const typeColor = useAlertTypeColor(type);
    const styles = getStyles(theme, { typeColor });
    const icon = useAlertTypeIcon(type, typeColor, theme.rem(1.25), styles.icon);
    const result = (React.createElement(View, { style: [styles.alert, margin, padding] },
        React.createElement(View, { style: styles.header },
            icon,
            React.createElement(EdgeText, { style: styles.title }, title)),
        message != null ? (React.createElement(EdgeText, { style: styles.message, numberOfLines: numberOfLines }, message)) : null,
        children));
    return onPress ? (React.createElement(TouchableOpacity, { onPress: onPress }, result)) : (result);
}
const getStyles = (theme, { typeColor }) => cacheStyles((theme) => ({
    alert: {
        borderWidth: theme.cardBorder,
        borderColor: typeColor,
        borderRadius: theme.cardBorderRadius,
        alignSelf: 'stretch'
    },
    header: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center'
    },
    title: {
        fontSize: theme.rem(0.75),
        color: typeColor
    },
    icon: {
        marginRight: theme.rem(0.5)
    },
    message: {
        fontSize: theme.rem(0.75),
        color: typeColor,
        fontFamily: theme.fontFaceDefault
    }
}))(theme);
