import * as React from 'react';
import { ScrollView, Text, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { GradientFadeOut } from '../modals/GradientFadeout';
import { useTheme } from '../services/ThemeContext';
export function ModalTitle(props) {
    const { center, children, icon = null, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(View, { style: styles.titleContainer },
        icon ? React.createElement(View, { style: styles.titleIconContainer }, icon) : null,
        React.createElement(Text, { style: [styles.titleText, center ? styles.titleCenter : null, padding] }, children)));
}
export function ModalMessage(props) {
    const { children, isWarning, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(Text, { style: [styles.messageText, padding, isWarning && styles.warningText] }, children));
}
export function ModalCloseArrow(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(TouchableOpacity, { onPress: props.onPress, style: styles.closeIcon },
        React.createElement(AntDesignIcon, { name: "close", size: theme.rem(1.25), color: theme.iconTappable })));
}
export function ModalFooter(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    const { fadeOut } = props;
    const footerFadeContainer = fadeOut === true ? styles.footerFadeContainer : undefined;
    const footerFade = fadeOut === true ? styles.footerFade : undefined;
    return (React.createElement(View, { style: footerFadeContainer },
        React.createElement(View, { style: footerFade },
            React.createElement(TouchableOpacity, { onPress: props.onPress, style: styles.closeIcon, accessibilityHint: "Close Modal" },
                React.createElement(AntDesignIcon, { name: "close", size: theme.rem(1.25), color: theme.iconTappable }))),
        fadeOut !== true ? null : React.createElement(GradientFadeOut, null)));
}
export function ModalScrollArea(props) {
    const { children, onCancel } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(View, null,
        React.createElement(ScrollView, { contentContainerStyle: styles.scrollPadding }, children),
        React.createElement(ModalFooter, { onPress: onCancel, fadeOut: true })));
}
const getStyles = cacheStyles((theme) => ({
    closeIcon: {
        alignItems: 'center',
        paddingTop: theme.rem(1)
    },
    scrollPadding: {
        paddingBottom: theme.rem(2.5)
    },
    titleContainer: {
        alignItems: 'center',
        flexDirection: 'row',
        margin: theme.rem(0.5)
    },
    titleIconContainer: {
        marginRight: theme.rem(0.5)
    },
    titleText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1.2),
        marginVertical: theme.rem(0.5)
    },
    titleCenter: {
        textAlign: 'center'
    },
    warningText: {
        color: theme.warningText
    },
    messageText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        marginVertical: theme.rem(0.5),
        textAlign: 'left'
    },
    footerFadeContainer: {
        marginBottom: theme.rem(-1)
    },
    footerFade: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        right: 0,
        zIndex: 1
    }
}));
